package TSimple;

use strict;
use warnings;

use Class::Trait 'base';

sub getName {
    return "TSimple";
}

1;
